@@ -1,4 +1,4 @@
-use crate::natives_and_messaging::WINDOWSTYLE_NORMAL;
+use crate::natives_and_messaging::WS_NORMAL;
 use crate::window::{Attributes, Frame};
 use crate::window::dialog::Dialog;
 
@@ -16,7 +16,7 @@ impl DemoDialog {
 
 impl Dialog for DemoDialog {
     fn attributes(&self) -> Attributes {
-        Attributes::new(WINDOWSTYLE_NORMAL, "Demo Dialog".to_string(), 320, 250, 50, 50)
+        Attributes::new(WS_NORMAL, "Demo Dialog".to_string(), 320, 250, 50, 50)
     }
 
     fn frame(&self) -> Frame {
