@@ -1,5 +1,6 @@
 use crate::io::storage::Storage;
 use crate::natives_and_messaging::*;
+use crate::widget::Widget;
 use crate::window::{Application, Frame, Attributes};
 
 pub struct DemoWindow {
@@ -33,6 +34,7 @@ impl Application for DemoWindow {
     }
 
     fn ui(&self,frame: Frame) {
+        Widget::new(WT_BUTTON, Attributes::new(0, "NXUI Button".to_string(), 350, 250, 100, 100), frame).show();
         frame.show();
     }
 
