@@ -1,6 +1,8 @@
 use crate::io::get_app_dirs;
 use crate::io::storage::Storage;
-use crate::window::{Application, Frame};
+use crate::natives_and_messaging::WT_BUTTON;
+use crate::widget::Widget;
+use crate::window::{Application, Attributes, Frame};
 
 #[cfg(windows)]
 /// Run nxui::window::Application
@@ -51,10 +53,11 @@ pub fn create_new_app(application: Box<dyn Application>) {
         let atom = RegisterClassA(&wc);
         debug_assert!(atom != 0);
 
-        let win = CreateWindowExA(application.advanced_options().get_style(), "window".as_ptr(), format!("{}\0",attributes.title).as_ptr(), attributes.style|WS_VISIBLE, attributes.x, attributes.y, attributes.width, attributes.height, 0, 0, instance, std::ptr::null_mut());
+        let win = CreateWindowExA(application.advanced_options().get_style(), "window".as_ptr(), format!("Button\0").as_ptr(), attributes.style|WS_VISIBLE, attributes.x, attributes.y, attributes.width, attributes.height, 0, 0, instance, std::ptr::null_mut());
         info!("A window has been created. handle: {}",win);
 
         let frame = Frame::new(win);
+        Widget::new(WT_BUTTON, Attributes::new(0, "NXUI Button".to_string(), 350, 250, 100, 100), frame).show();
         info!("Frame has been created.");
         info!("UI Phase");
         application.ui(frame);
